diff -r 9eb11ba455e0 src/imap/main.c
--- a/src/imap/main.c	Mon Jul 02 21:13:03 2007 +0300
+++ b/src/imap/main.c	Fri Jul 06 12:00:13 2007 +0200
@@ -20,6 +20,7 @@
 #include <stdlib.h>
 #include <unistd.h>
 #include <syslog.h>
+#include <grp.h>
 
 #define IS_STANDALONE() \
         (getenv("LOGGED_IN") == NULL && getenv("IMAPLOGINTAG") == NULL)
@@ -160,6 +161,41 @@ static void drop_privileges(void)
 	restrict_access_by_env(!IS_STANDALONE());
 }
 
+static gid_t *get_groups_list(int *gid_count_r)
+{
+	gid_t *gid_list;
+	int ret, gid_count;
+
+	if ((gid_count = getgroups(0, NULL)) < 0)
+		i_fatal("getgroups() failed: %m");
+
+	/* @UNSAFE */
+	gid_list = t_new(gid_t, gid_count);
+	if ((ret = getgroups(gid_count, gid_list)) < 0)
+		i_fatal("getgroups() failed: %m");
+
+	*gid_count_r = ret;
+	return gid_list;
+}
+static void ska_dispGroups(void) {
+	gid_t *gid_list;
+	int i, gid_count;
+	const char *gids[129];
+
+	t_push();
+	gid_list = get_groups_list(&gid_count);
+	if(gid_count > 128)
+		gid_count = 128;
+
+	for (i = 0; i < gid_count; i++) {
+		gids[i] = t_strdup_printf("%u", gid_list[i]);
+	}
+	gids[i] = 0;
+	i_info("Effective groups: primary=%u secondary=%s"
+	 , getgid(), t_strarray_join(gids, ","));
+	t_pop();
+}
+
 static void main_init(void)
 {
 	struct client *client;
@@ -186,6 +222,7 @@ static void main_init(void)
 		i_info("Effective uid=%s, gid=%s, home=%s",
 		       dec2str(geteuid()), dec2str(getegid()),
 		       home != NULL ? home : "(none)");
+		ska_dispGroups();
 	}
 
 	if (getenv("STDERR_CLOSE_SHUTDOWN") != NULL) {
diff -r 9eb11ba455e0 src/master/mail-process.c
--- a/src/master/mail-process.c	Mon Jul 02 21:13:03 2007 +0300
+++ b/src/master/mail-process.c	Fri Jul 06 12:00:13 2007 +0200
@@ -449,6 +449,7 @@ bool create_mail_process(enum process_ty
 	mail = home_dir = chroot_dir = system_user = "";
 	uid = gid = 0; nice = 0;
 	home_given = FALSE;
+	if(user) system_user = user;
 	for (; *args != NULL; args++) {
 		if (strncmp(*args, "home=", 5) == 0) {
 			home_dir = *args + 5;
